@@ -71,7 +71,7 @@ class PyDoctestService():
         # Validate top-level functions in module
         fns = self.get_global_functions(module_type)
         for fn in fns:
-            function_result = validate_function(fn, self.config)
+            function_result = validate_function(fn, self.config, module_type)
             if function_result.result == ResultType.FAILED:
                 result.result = ResultType.FAILED
             result.function_results.append(function_result)
@@ -79,15 +79,14 @@ class PyDoctestService():
         # Validate top-level classes in module
         classes = self.get_classes(module_type)
         for cl in classes:
-            result.class_results.append(validate_class(cl, self.config))
+            result.class_results.append(validate_class(cl, self.config, module_type))
 
         return result
 
     def get_global_functions(self, module: ModuleType) -> List[FunctionType]:
         fns = []
-        for name, obj in inspect.getmembers(module):
-            if inspect.isfunction(obj):
-                fns.append(obj)
+        for name, obj in inspect.getmembers(module, lambda x: inspect.isfunction(x) and x.__module__ == module.__name__):
+            fns.append(obj)
         return fns
 
     def get_classes(self, module: ModuleType) -> List[FunctionType]:
@@ -137,6 +136,16 @@ def get_configuration(root_dir: str, config_path: Optional[str] = None) -> Confi
 
 
 def get_reporter(reporter: Optional[str], config: Configuration) -> Reporter:
+    """We offer to output results using either TextReporter and JSONReporter.
+    This list of reporters can be extended with more reporters as they simply implement a get_output function.
+
+    Args:
+        reporter (Optional[str]): Desired reporter [text | json]
+        config (Configuration): The configuration currently used.
+
+    Returns:
+        Reporter: Reporter if provided, otherwise text.
+    """
     if reporter is None:
         return REPORTERS['text'](config)
 
@@ -148,6 +157,8 @@ def get_reporter(reporter: Optional[str], config: Configuration) -> Reporter:
 
 
 def main() -> None:
+    """Main function invoked when running script.
+    """
     # TODO: Could allow arguments directly to pydoctest for overriding .json config arguments
     parser = argparse.ArgumentParser()
     parser.add_argument("--config", help="Path to config JSON file, e.g. pydoctest.json")
@@ -174,7 +185,8 @@ def main() -> None:
     if config.verbosity != Verbosity.QUIET:
         output = reporter.get_output(result)
         counts = result.get_counts()
-        output += f"Tested {counts.function_count} function(s) across {counts.module_count} module(s)."
+        output += f"Tested {counts.get_total()} function(s) across {counts.module_count} module(s).\n"
+        output += f"Succeeded: {counts.functions_succeeded}, Failed: {counts.functions_failed}, Skipped: {counts.functions_skipped}"
         print(output)
 
     # return 0 if validation succeeds
